@@ -63,6 +63,10 @@ barbican_opts = [
                default=60,
                help='Number of times to retry poll for key creation '
                     'completion'),
+    cfg.BoolOpt('verify_ssl',
+                default=True,
+                help='Specifies if insecure TLS (https) requests. If False, '
+                     'the server\'s certificate will not be validated'),
 ]
 
 BARBICAN_OPT_GROUP = 'barbican'
@@ -109,7 +113,8 @@ class BarbicanKeyManager(key_manager.KeyManager):
 
         try:
             auth = self._get_keystone_auth(context)
-            sess = session.Session(auth=auth)
+            sess = session.Session(auth=auth,
+                                   verify=self.conf.barbican.verify_ssl)
 
             self._barbican_endpoint = self._get_barbican_endpoint(auth, sess)
             self._barbican_client = barbican_client.Client(
@@ -512,12 +517,10 @@ class BarbicanKeyManager(key_manager.KeyManager):
     def get(self, context, managed_object_id):
         """Retrieves the specified managed object.
 
-        Currently only supports retrieving symmetric keys.
-
         :param context: contains information of the user and the environment
                         for the request (castellan/context.py)
         :param managed_object_id: the UUID of the object to retrieve
-        :return: SymmetricKey representation of the key
+        :return: ManagedObject representation of the managed object
         :raises KeyManagerError: if object retrieval fails
         :raises ManagedObjectNotFoundError: if object not found
         """
@@ -540,7 +543,7 @@ class BarbicanKeyManager(key_manager.KeyManager):
         :param context: contains information of the user and the environment
                      for the request (castellan/context.py)
         :param managed_object_id: the UUID of the object to delete
-        :raises KeyManagerError: if key deletion fails
+        :raises KeyManagerError: if object deletion fails
         :raises ManagedObjectNotFoundError: if the object could not be found
         """
         barbican_client = self._get_barbican_client(context)
